@@ -204,15 +204,12 @@ def test_register_decorator(xession):
     aliases = Aliases()
 
     @aliases.register
-    def debug():
-        ...
+    def debug(): ...
 
     @aliases.register("name")
-    def with_options():
-        ...
+    def with_options(): ...
 
     @aliases.register
-    def _private():
-        ...
+    def _private(): ...
 
     assert set(aliases) == {"debug", "name", "private"}
