@@ -2,6 +2,7 @@
 
 Written using a hybrid of ``tokenize`` and PLY.
 """
+
 import io
 
 # 'keyword' interferes with ast.keyword
@@ -266,11 +267,7 @@ def _make_matcher_handler(tok, typ, pymode, ender, handlers):
     matcher = (
         ")"
         if tok.endswith("(")
-        else "}"
-        if tok.endswith("{")
-        else "]"
-        if tok.endswith("[")
-        else None
+        else "}" if tok.endswith("{") else "]" if tok.endswith("[") else None
     )
 
     def _inner_handler(state, token):
